@@ -34,7 +34,7 @@ class TQPushButton;
 
 class BookmarksDlg : public TQDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
