@@ -62,7 +62,7 @@ BookWidget::BookWidget(TQWidget *parent, const char *name)
 	Theme::self()->loadTheme("default");
 
 	setWFlags(TQt::WNoAutoErase);
-	setFocusPolicy(TQ_StrongFocus);
+	setFocusPolicy(TQWidget::StrongFocus);
 	
 	connect(&m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(loadLine()));
 	connect(m_renderer.get(), TQT_SIGNAL(renderingFinished()), this, TQT_SLOT(renderingFinished()));
