@@ -39,7 +39,7 @@ class KProgressDialog;
  */
 class BookWidget : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	
