@@ -65,7 +65,7 @@ private:
 */
 class Renderer : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	Renderer();
